===============================
snooper
===============================


.. image:: https://img.shields.io/pypi/v/snooper.svg
        :target: https://pypi.python.org/pypi/snooper

.. image:: https://img.shields.io/travis/kintoandar/snooper.svg
        :target: https://travis-ci.org/kintoandar/snooper

.. image:: https://readthedocs.org/projects/snooper/badge/?version=latest
        :target: https://snooper.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/kintoandar/snooper/shield.svg
     :target: https://pyup.io/repos/github/kintoandar/snooper/
     :alt: Updates


Snooper provides a simple way for finding AWS resources.


* Free software: MIT license
* Documentation: https://snooper.readthedocs.io.


Features
--------

* Currently supporting:
* EC2 stopped instances
* EBS unused volumes
* EC2 running instances
* EBS in use volumes
* List available AWS regions
